summaryrefslogtreecommitdiffstats
path: root/kommander/working
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:54:04 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:54:04 +0000
commitdc6b8e72fed2586239e3514819238c520636c9d9 (patch)
tree88b200df0a0b7fab9d6f147596173556f1ed9a13 /kommander/working
parent6927d4436e54551917f600b706a8d6109e49de1c (diff)
downloadtdewebdev-dc6b8e72fed2586239e3514819238c520636c9d9.tar.gz
tdewebdev-dc6b8e72fed2586239e3514819238c520636c9d9.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdewebdev@1157656 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kommander/working')
-rw-r--r--kommander/working/plugintemplate/plugin.cpp6
-rw-r--r--kommander/working/plugintemplate/widget.cpp32
-rw-r--r--kommander/working/plugintemplate/widget.h28
3 files changed, 33 insertions, 33 deletions
diff --git a/kommander/working/plugintemplate/plugin.cpp b/kommander/working/plugintemplate/plugin.cpp
index e6b506cc..b6e1a0a0 100644
--- a/kommander/working/plugintemplate/plugin.cpp
+++ b/kommander/working/plugintemplate/plugin.cpp
@@ -11,15 +11,15 @@ class %{APPNAME}Plugin : public KommanderPlugin
{
public:
%{APPNAME}Plugin();
- virtual QWidget *create( const QString &className, QWidget *parent = 0, const char *name = 0);
+ virtual TQWidget *create( const TQString &className, TQWidget *parent = 0, const char *name = 0);
};
%{APPNAME}Plugin::%{APPNAME}Plugin()
{
- addWidget( "%{APPNAME}", "Custom", i18n("Kommander %{APPNAME} plugin."), new QIconSet(KGlobal::iconLoader()->loadIcon("%{APPNAMELC}", KIcon::NoGroup, KIcon::SizeMedium)) );
+ addWidget( "%{APPNAME}", "Custom", i18n("Kommander %{APPNAME} plugin."), new TQIconSet(KGlobal::iconLoader()->loadIcon("%{APPNAMELC}", KIcon::NoGroup, KIcon::SizeMedium)) );
}
-QWidget *%{APPNAME}Plugin::create( const QString &className, QWidget *parent, const char *name)
+TQWidget *%{APPNAME}Plugin::create( const TQString &className, TQWidget *parent, const char *name)
{
if (className == "%{APPNAME}")
return new %{APPNAME}(parent, name);
diff --git a/kommander/working/plugintemplate/widget.cpp b/kommander/working/plugintemplate/widget.cpp
index 73ec0278..2378e87a 100644
--- a/kommander/working/plugintemplate/widget.cpp
+++ b/kommander/working/plugintemplate/widget.cpp
@@ -16,10 +16,10 @@ enum Functions {
LastFunction
};
-%{APPNAME}::%{APPNAME}(QWidget *parent, const char *name)
- : QWidget(parent, name), KommanderWidget(this)
+%{APPNAME}::%{APPNAME}(TQWidget *parent, const char *name)
+ : TQWidget(parent, name), KommanderWidget(this)
{
- QStringList states;
+ TQStringList states;
states << "default";
setStates(states);
setDisplayStates(states);
@@ -29,7 +29,7 @@ enum Functions {
if (KommanderWidget::inEditor)
{
setPixmap(KGlobal::iconLoader()->loadIcon("%{APPNAMELC}", KIcon::NoGroup, KIcon::SizeMedium));
- setFrameStyle(QFrame::Box | QFrame::Plain);
+ setFrameStyle(TQFrame::Box | TQFrame::Plain);
setLineWidth(1);
setAlignment(Qt::AlignCenter);
}
@@ -40,8 +40,8 @@ enum Functions {
KommanderPlugin::setDefaultGroup(Group::DCOP);
//CHANGE THE BELOW LINES TO MATCH YOUR FUNCTIONS NAMES AND SIGNATURE
- KommanderPlugin::registerFunction(Function1, "function1(QString widget, QString arg1, int arg2)", i18n("Call function1 with two arguments, second is optional."), 2, 3);
- KommanderPlugin::registerFunction(Function2, "function2(QString widget)", i18n("Get a QString as a result of function2."), 1);
+ KommanderPlugin::registerFunction(Function1, "function1(TQString widget, TQString arg1, int arg2)", i18n("Call function1 with two arguments, second is optional."), 2, 3);
+ KommanderPlugin::registerFunction(Function2, "function2(TQString widget)", i18n("Get a TQString as a result of function2."), 1);
}
@@ -49,9 +49,9 @@ enum Functions {
{
}
-QString %{APPNAME}::currentState() const
+TQString %{APPNAME}::currentState() const
{
- return QString("default");
+ return TQString("default");
}
bool %{APPNAME}::isKommanderWidget() const
@@ -59,22 +59,22 @@ bool %{APPNAME}::isKommanderWidget() const
return true;
}
-QStringList %{APPNAME}::associatedText() const
+TQStringList %{APPNAME}::associatedText() const
{
return KommanderWidget::associatedText();
}
-void %{APPNAME}::setAssociatedText(const QStringList& a_atext)
+void %{APPNAME}::setAssociatedText(const TQStringList& a_atext)
{
KommanderWidget::setAssociatedText(a_atext);
}
-void %{APPNAME}::setPopulationText(const QString& a_text)
+void %{APPNAME}::setPopulationText(const TQString& a_text)
{
KommanderWidget::setPopulationText(a_text);
}
-QString %{APPNAME}::populationText() const
+TQString %{APPNAME}::populationText() const
{
return KommanderWidget::populationText();
}
@@ -84,10 +84,10 @@ void %{APPNAME}::populate()
KommanderWidget::evalAssociatedText(populationText());
}
-void %{APPNAME}::contextMenuEvent( QContextMenuEvent * e )
+void %{APPNAME}::contextMenuEvent( TQContextMenuEvent * e )
{
e->accept();
- QPoint p = e->globalPos();
+ TQPoint p = e->globalPos();
emit contextMenuRequested(p.x(), p.y());
}
@@ -97,7 +97,7 @@ bool %{APPNAME}::isFunctionSupported(int f)
return (f >= FirstFunction && f <= LastFunction); //see specials.h for other DCOP functions you might want to support
}
-QString %{APPNAME}::handleDCOP(int function, const QStringList& args)
+TQString %{APPNAME}::handleDCOP(int function, const TQStringList& args)
{
switch (function)
{
@@ -110,7 +110,7 @@ QString %{APPNAME}::handleDCOP(int function, const QStringList& args)
default:
return KommanderWidget::handleDCOP(function, args);
}
- return QString::null;
+ return TQString::null;
}
#include "%{APPNAMELC}.moc"
diff --git a/kommander/working/plugintemplate/widget.h b/kommander/working/plugintemplate/widget.h
index 56e87f91..1ec87a5e 100644
--- a/kommander/working/plugintemplate/widget.h
+++ b/kommander/working/plugintemplate/widget.h
@@ -2,8 +2,8 @@
#ifndef %{APPNAMEUC}_WIDGET_H
#define %{APPNAMEUC}_WIDGET_H
-#include <qwidget.h>
-#include <qstring.h>
+#include <tqwidget.h>
+#include <tqstring.h>
#include <kparts/part.h>
@@ -11,35 +11,35 @@
class QStringList;
-//replace QWidget with the widget you want to derive from
-class %{APPNAME}: public QWidget, public KommanderWidget
+//replace TQWidget with the widget you want to derive from
+class %{APPNAME}: public TQWidget, public KommanderWidget
{
Q_OBJECT
- Q_PROPERTY(QString populationText READ populationText WRITE setPopulationText DESIGNABLE false)
- Q_PROPERTY(QStringList associations READ associatedText WRITE setAssociatedText DESIGNABLE false)
+ Q_PROPERTY(TQString populationText READ populationText WRITE setPopulationText DESIGNABLE false)
+ Q_PROPERTY(TQStringList associations READ associatedText WRITE setAssociatedText DESIGNABLE false)
Q_PROPERTY(bool KommanderWidget READ isKommanderWidget)
public:
- %{APPNAME}(QWidget *parent, const char* name);
+ %{APPNAME}(TQWidget *parent, const char* name);
~%{APPNAME}();
virtual bool isKommanderWidget() const;
- virtual void setAssociatedText(const QStringList&);
- virtual QStringList associatedText() const;
- virtual QString currentState() const;
- virtual QString populationText() const;
- virtual void setPopulationText(const QString&);
+ virtual void setAssociatedText(const TQStringList&);
+ virtual TQStringList associatedText() const;
+ virtual TQString currentState() const;
+ virtual TQString populationText() const;
+ virtual void setPopulationText(const TQString&);
virtual void populate();
- virtual QString handleDCOP(int function, const QStringList& args);
+ virtual TQString handleDCOP(int function, const TQStringList& args);
virtual bool isFunctionSupported(int function);
signals:
void contextMenuRequested(int xpos, int ypos);
protected:
- void contextMenuEvent( QContextMenuEvent * e );
+ void contextMenuEvent( TQContextMenuEvent * e );
};